All of lore.kernel.org
 help / color / mirror / Atom feed
From: Thomas Gleixner <tglx@linutronix.de>
To: Fernando Pablo Lopez-Lezcano <nando@ccrma.Stanford.EDU>
Cc: Ingo Molnar <mingo@elte.hu>, LKML <linux-kernel@vger.kernel.org>,
	Lee Revell <rlrevell@joe-job.com>,
	Rui Nuno Capela <rncbc@rncbc.org>,
	Mark_H_Johnson@Raytheon.com, "K.R. Foley" <kr@cybsft.com>,
	Bill Huey <bhuey@lnxw.com>, Adam Heath <doogie@debian.org>,
	Florian Schmidt <mista.tapas@gmx.net>,
	Michal Schmidt <xschmi00@stud.feec.vutbr.cz>
Subject: Re: [patch] Real-Time Preemption, -RT-2.6.9-rc4-mm1-U7
Date: Wed, 20 Oct 2004 07:02:21 +0200	[thread overview]
Message-ID: <1098248541.12223.1450.camel@thomas> (raw)
In-Reply-To: <1098229166.12223.1153.camel@thomas>

[-- Attachment #1: Type: text/plain, Size: 293 bytes --]

On Wed, 2004-10-20 at 01:39, Thomas Gleixner wrote:
> That's in scsi_error_handler() where a mutex is initialized locked and
> then acquired again. This triggers the deadlock/correctness check.

Some more fixes

- scsi_error_handler() fix

- device subsystem device_remove locking fix

tglx



[-- Attachment #2: driver.patch --]
[-- Type: text/x-patch, Size: 2610 bytes --]

diff --exclude='*~' -urN 2.6.9-rc4-mm1-RT-U7/drivers/base/bus.c 2.6.9-rc4-mm1-RT-U7-work/drivers/base/bus.c
--- 2.6.9-rc4-mm1-RT-U7/drivers/base/bus.c	2004-10-12 09:41:05.000000000 +0200
+++ 2.6.9-rc4-mm1-RT-U7-work/drivers/base/bus.c	2004-10-20 03:04:29.000000000 +0200
@@ -65,7 +65,7 @@
 static void driver_release(struct kobject * kobj)
 {
 	struct device_driver * drv = to_driver(kobj);
-	up(&drv->unload_sem);
+	complete(&drv->unload_done);
 }
 
 static struct kobj_type ktype_driver = {
diff --exclude='*~' -urN 2.6.9-rc4-mm1-RT-U7/include/linux/device.h 2.6.9-rc4-mm1-RT-U7-work/include/linux/device.h
--- 2.6.9-rc4-mm1-RT-U7/include/linux/device.h	2004-10-12 09:41:58.000000000 +0200
+++ 2.6.9-rc4-mm1-RT-U7-work/include/linux/device.h	2004-10-20 03:05:02.000000000 +0200
@@ -102,7 +102,7 @@
 	char			* name;
 	struct bus_type		* bus;
 
-	struct semaphore	unload_sem;
+	struct completion	unload_done;
 	struct kobject		kobj;
 	struct list_head	devices;
 
diff --exclude='*~' -urN 2.6.9-rc4-mm1-RT-U7/drivers/scsi/hosts.c 2.6.9-rc4-mm1-RT-U7-work/drivers/scsi/hosts.c
--- 2.6.9-rc4-mm1-RT-U7/drivers/scsi/hosts.c	2004-10-12 09:41:34.000000000 +0200
+++ 2.6.9-rc4-mm1-RT-U7-work/drivers/scsi/hosts.c	2004-10-20 03:32:10.000000000 +0200
@@ -149,7 +149,7 @@
 		DECLARE_COMPLETION(sem);
 		shost->eh_notify = &sem;
 		shost->eh_kill = 1;
-		up(shost->eh_wait);
+		wake_up(shost->eh_wait);
 		wait_for_completion(&sem);
 		shost->eh_notify = NULL;
 	}
diff --exclude='*~' -urN 2.6.9-rc4-mm1-RT-U7/drivers/scsi/scsi_error.c 2.6.9-rc4-mm1-RT-U7-work/drivers/scsi/scsi_error.c
--- 2.6.9-rc4-mm1-RT-U7/drivers/scsi/scsi_error.c	2004-10-19 20:29:46.000000000 +0200
+++ 2.6.9-rc4-mm1-RT-U7-work/drivers/scsi/scsi_error.c	2004-10-20 05:31:20.000000000 +0200
@@ -49,7 +49,7 @@
 void scsi_eh_wakeup(struct Scsi_Host *shost)
 {
 	if (shost->host_busy == shost->host_failed) {
-		up(shost->eh_wait);
+		wake_up(shost->eh_wait);
 		SCSI_LOG_ERROR_RECOVERY(5,
 				printk("Waking error handler thread\n"));
 	}
@@ -1599,9 +1599,8 @@
 {
 	struct Scsi_Host *shost = (struct Scsi_Host *) data;
 	int rtn;
-	DECLARE_MUTEX(sem);
+	DECLARE_WAIT_QUEUE_HEAD(eh_wait);
 
-	init_MUTEX_LOCKED(&sem);
 	/*
 	 *    Flush resources
 	 */
@@ -1610,7 +1609,7 @@
 
 	current->flags |= PF_NOFREEZE;
 
-	shost->eh_wait = &sem;
+	shost->eh_wait = &eh_wait;
 	shost->ehandler = current;
 
 	/*
@@ -1632,15 +1631,12 @@
 						  " sleeping\n",shost->host_no));
 
 		/*
-		 * Note - we always use down_interruptible with the semaphore
-		 * even if the module was loaded as part of the kernel.  The
-		 * reason is that down() will cause this thread to be counted
-		 * in the load average as a running process, and down
-		 * interruptible doesn't.  Given that we need to allow this
-		 * thread to die if the driver was loaded as a module, using
-		 * semaphores isn't unreasonable.
+		 * Wait, until somebody decides to wake us due to an error
+		 * or because we should be killed
 		 */
-		down_interruptible(&sem);
+		wait_event_interruptible(eh_wait, shost->eh_kill ||
+				(shost->host_busy == shost->host_failed)); 
+	
 		if (shost->eh_kill)
 			break;
 
diff --exclude='*~' -urN 2.6.9-rc4-mm1-RT-U7/include/scsi/scsi_host.h 2.6.9-rc4-mm1-RT-U7-work/include/scsi/scsi_host.h
--- 2.6.9-rc4-mm1-RT-U7/include/scsi/scsi_host.h	2004-10-12 09:42:00.000000000 +0200
+++ 2.6.9-rc4-mm1-RT-U7-work/include/scsi/scsi_host.h	2004-10-20 03:42:05.000000000 +0200
@@ -396,7 +396,7 @@
 
 	struct list_head	eh_cmd_q;
 	struct task_struct    * ehandler;  /* Error recovery thread. */
-	struct semaphore      * eh_wait;   /* The error recovery thread waits
+	wait_queue_head_t     * eh_wait;   /* The error recovery thread waits
 					      on this. */
 	struct completion     * eh_notify; /* wait for eh to begin or end */
 	struct semaphore      * eh_action; /* Wait for specific actions on the

  reply	other threads:[~2004-10-20  5:21 UTC|newest]

Thread overview: 948+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2004-10-11 18:23 [patch] CONFIG_PREEMPT_REALTIME, 'Fully Preemptible Kernel', VP-2.6.9-rc4-mm1-T4 Mark_H_Johnson
2004-10-11 21:59 ` [patch] VP-2.6.9-rc4-mm1-T5 Ingo Molnar
2004-10-11 22:57   ` Florian Schmidt
2004-10-11 23:14     ` Florian Schmidt
2004-10-12  0:52       ` Lee Revell
2004-10-12  8:22         ` Wen-chien Jesse Sung
2004-10-12  6:12       ` Ingo Molnar
2004-10-12 10:45         ` Florian Schmidt
2004-10-12  0:11   ` Rui Nuno Capela
2004-10-12  0:57   ` Lee Revell
2004-10-12  6:37     ` Ingo Molnar
2004-10-12  3:51   ` K.R. Foley
2004-10-12  6:02     ` Ingo Molnar
2004-10-12 11:08       ` K.R. Foley
2004-10-12 11:43         ` Ingo Molnar
2004-10-12  9:15   ` [patch] VP-2.6.9-rc4-mm1-T6 Ingo Molnar
2004-10-12  9:31     ` Wen-chien Jesse Sung
2004-10-12 10:35       ` Ingo Molnar
2004-10-12 11:32         ` Wen-chien Jesse Sung
2004-10-12  9:42     ` Ingo Molnar
2004-10-12  9:53       ` Ingo Molnar
2004-10-12 12:33     ` Ingo Molnar
2004-10-12 13:59       ` VP-2.6.9-rc4-mm1-T7 Rui Nuno Capela
2004-10-12 14:23         ` VP-2.6.9-rc4-mm1-T7 Ingo Molnar
2004-10-12 15:12       ` [patch] VP-2.6.9-rc4-mm1-T6 K.R. Foley
2004-10-12 15:27         ` Ingo Molnar
2004-10-12 16:57           ` K.R. Foley
2004-10-12 19:54       ` [patch] VP-2.6.9-rc4-mm1-T8 Ingo Molnar
2004-10-12 20:57         ` K.R. Foley
2004-10-13  5:45           ` Ingo Molnar
2004-10-13 14:00             ` K.R. Foley
2004-10-13  6:15         ` [patch] VP-2.6.9-rc4-mm1-T9 Ingo Molnar
2004-10-13  9:15           ` Rui Nuno Capela
2004-10-13 14:52           ` K.R. Foley
2004-10-13 16:53           ` Radoslaw Szkodzinski
2004-10-14  0:24           ` [patch] Real-Time Preemption, -VP-2.6.9-rc4-mm1-U0 Ingo Molnar
2004-10-14  1:27             ` Adam Heath
2004-10-14  1:31               ` Ingo Molnar
2004-10-14  2:22                 ` Adam Heath
2004-10-14  1:36               ` Ingo Molnar
2004-10-14  2:45             ` K.R. Foley
2004-10-14  3:59             ` K.R. Foley
2004-10-14  8:57             ` Florian Schmidt
2004-10-14  9:19               ` Ingo Molnar
2004-10-14  9:42                 ` Florian Schmidt
2004-10-14  9:36                   ` Ingo Molnar
2004-10-14 10:00                 ` Florian Schmidt
2004-10-14 10:22                   ` Rui Nuno Capela
2004-10-14 10:48                     ` Florian Schmidt
2004-10-14 10:54                       ` K.R. Foley
2004-10-14 11:16                         ` Florian Schmidt
2004-10-14 11:23                           ` Florian Schmidt
2004-10-14 11:42                           ` Florian Schmidt
2004-10-14 13:33                             ` Florian Schmidt
2004-10-14 17:43                 ` Miquel van Smoorenburg
2004-10-14 14:31             ` [patch] Real-Time Preemption, -VP-2.6.9-rc4-mm1-U1 Ingo Molnar
2004-10-14 17:34               ` Adam Heath
2004-10-14 22:16                 ` Adam Heath
2004-10-14 22:24                   ` Ingo Molnar
2004-10-14 19:42               ` Daniel Walker
2004-10-14 19:57                 ` Ingo Molnar
2004-10-14 20:34                   ` Daniel Walker
     [not found]               ` <200410142216.23572.l_allegrucci@yahoo.it>
2004-10-14 20:21                 ` Lee Revell
2004-10-14 20:28               ` Lorenzo Allegrucci
2004-10-14 20:39               ` K.R. Foley
2004-10-14 22:52               ` Radoslaw Szkodzinski
2004-10-14 23:42               ` [patch] Real-Time Preemption, -VP-2.6.9-rc4-mm1-U2 Ingo Molnar
2004-10-15  0:31                 ` Adam Heath
2004-10-15  0:41                   ` Adam Heath
2004-10-15  0:53                     ` Adam Heath
2004-10-15  7:14                     ` Ingo Molnar
2004-10-15  2:23                 ` Bill Huey
2004-10-15  2:40                   ` K.R. Foley
2004-10-15  2:47                     ` Bill Huey
2004-10-15  3:19                       ` K.R. Foley
2004-10-15  3:47                         ` Bill Huey
2004-10-15  3:48                           ` Bill Huey
2004-10-15  7:08                   ` Ingo Molnar
2004-10-15  8:21                     ` Bill Huey
2004-10-15 11:47                     ` K.R. Foley
2004-10-15 11:58                       ` Ingo Molnar
2004-10-15  2:33                 ` Adam Heath
2004-10-15 10:26                 ` [patch] Real-Time Preemption, -VP-2.6.9-rc4-mm1-U3 Ingo Molnar
2004-10-15 11:59                   ` Dominik Karall
2004-10-15 12:03                     ` Ingo Molnar
2004-10-15 16:48                     ` Lee Revell
2004-10-15 17:40                       ` Adam Heath
2004-10-15 17:54                   ` K.R. Foley
2004-10-15 18:16                   ` K.R. Foley
2004-10-15 20:29                   ` Gunther Persoons
2004-10-15 23:16                   ` Bill Huey
2004-10-16  0:21                     ` Bill Huey
2004-10-16  6:48                     ` Ingo Molnar
2004-10-16  1:00                   ` Lee Revell
2004-10-16  2:35                     ` Lee Revell
2004-10-16  6:42                       ` Ingo Molnar
2004-10-16  9:02                         ` Lee Revell
2004-10-16 10:36                           ` Ingo Molnar
2004-10-16 11:03                             ` Rui Nuno Capela
2004-10-16 11:12                               ` Ingo Molnar
2004-10-16 11:55                                 ` Rui Nuno Capela
2004-10-16 12:01                                   ` Ingo Molnar
2004-10-16 12:32                             ` K.R. Foley
2004-10-17 13:14                             ` Rui Nuno Capela
2004-10-17 13:21                               ` Ingo Molnar
     [not found]                                 ` <32793.192.168.1.5.1098023139.squirrel@192.168.1.5>
2004-10-17 16:12                                   ` Ingo Molnar
2004-10-17 17:20                                     ` Rui Nuno Capela
2004-10-17 17:27                                       ` Ingo Molnar
2004-10-17 16:47                                   ` Ingo Molnar
2004-10-17 19:05                                     ` Rui Nuno Capela
2004-10-17 19:24                                       ` Ingo Molnar
2004-10-17 20:23                                         ` Rui Nuno Capela
2004-10-16 10:29                       ` Rui Nuno Capela
2004-10-16 12:54                         ` K.R. Foley
2004-10-16 13:04                           ` Ingo Molnar
2004-10-16 13:07                             ` K.R. Foley
2004-10-16 13:41                           ` Rui Nuno Capela
2004-10-16 13:55                             ` K.R. Foley
2004-10-16  2:58                   ` Adam Heath
2004-10-16  7:56                     ` Ingo Molnar
2004-10-16  8:18                       ` Ingo Molnar
2004-10-16 18:38                       ` Adam Heath
2004-10-16  6:13                   ` Lee Revell
2004-10-16 14:21                   ` Dominik Karall
2004-10-16 15:24                     ` Ingo Molnar
2004-10-16 20:30                       ` Dominik Karall
2004-10-16 20:31                         ` Lee Revell
2004-10-16 21:44                           ` Dominik Karall
2004-10-17  5:21                             ` Ingo Molnar
2004-10-17 15:32                             ` OGAWA Hirofumi
2004-10-17 17:46                               ` Dominik Karall
2004-10-18  3:50                                 ` OGAWA Hirofumi
2004-10-21 10:24                                   ` Dominik Karall
2004-10-16 15:33                   ` [patch] Real-Time Preemption, -VP-2.6.9-rc4-mm1-U4 Ingo Molnar
2004-10-16 17:11                     ` K.R. Foley
2004-10-16 19:25                       ` Ingo Molnar
2004-10-16 18:54                     ` Adam Heath
2004-10-16 19:24                       ` Ingo Molnar
2004-10-16 19:27                         ` Robert Love
2004-10-16 19:35                         ` Adam Heath
2004-10-16 19:29                     ` Adam Heath
2004-10-16 19:36                       ` Ingo Molnar
2004-10-16 19:59                         ` Adam Heath
2004-10-16 20:14                           ` Ingo Molnar
2004-10-16 20:39                             ` john cooper
2004-10-16 21:02                               ` Ingo Molnar
2004-10-16 21:15                                 ` Esben Nielsen
2004-10-16 23:41                                   ` Sam Ravnborg
2004-10-17 17:03                     ` Florian Schmidt
2004-10-17 16:55                       ` Ingo Molnar
2004-10-17 17:53                         ` Florian Schmidt
2004-10-17 17:40                           ` Ingo Molnar
2004-10-18 14:50                     ` [patch] Real-Time Preemption, -RT-2.6.9-rc4-mm1-U5 Ingo Molnar
2004-10-18 15:58                       ` Jason Munro
2004-10-18 17:08                       ` Adam Heath
2004-10-18 17:12                         ` Ingo Molnar
2004-10-18 17:57                       ` Adam Heath
2004-10-18 18:18                         ` Ingo Molnar
2004-10-18 20:58                           ` Adam Heath
2004-10-18 21:06                             ` Ingo Molnar
2004-10-18 21:21                               ` Adam Heath
2004-10-18 18:44                       ` K.R. Foley
2004-10-18 18:49                         ` Ingo Molnar
2004-10-18 19:17                           ` K.R. Foley
2004-10-18 19:32                       ` Bill Huey
2004-10-18 19:34                         ` Bill Huey
2004-10-18 19:36                         ` Ingo Molnar
2004-10-18 19:40                           ` Bill Huey
2004-10-18 19:46                             ` Ingo Molnar
2004-10-18 19:52                               ` Bill Huey
2004-10-19  1:27                       ` Adam Heath
2004-10-19  8:09                       ` Thomas Gleixner
2004-10-19  8:12                       ` Thomas Gleixner
2004-10-19  9:04                         ` Ingo Molnar
2004-10-19  9:03                           ` Thomas Gleixner
2004-10-19  9:34                             ` Ingo Molnar
2004-10-19  9:50                               ` Ingo Molnar
2004-10-19 10:12                               ` Thomas Gleixner
2004-10-19 11:07                                 ` Ingo Molnar
2004-10-19 11:14                                   ` Thomas Gleixner
2004-10-19 10:34                       ` Michal Schmidt
2004-10-19 12:46                       ` [patch] Real-Time Preemption, -RT-2.6.9-rc4-mm1-U6 Ingo Molnar
2004-10-19 14:46                         ` Ingo Molnar
2004-10-19 15:23                           ` Rui Nuno Capela
2004-10-19 15:44                             ` Thomas Gleixner
2004-10-19 15:57                               ` Ingo Molnar
2004-10-19 16:44                                 ` Thomas Gleixner
2004-10-19 17:58                                   ` Thomas Gleixner
2004-10-19 18:26                                     ` Ingo Molnar
2004-10-19 20:04                                       ` Thomas Gleixner
2004-10-19 15:50                             ` Ingo Molnar
2004-10-19 16:01                               ` K.R. Foley
2004-10-19 16:20                               ` Ingo Molnar
2004-10-19 16:28                                 ` Ingo Molnar
2004-10-19 16:31                                   ` Ingo Molnar
2004-10-19 17:17                                     ` Ingo Molnar
2004-10-19 16:50                             ` Florian Schmidt
2004-10-19 16:56                               ` Ingo Molnar
2004-10-19 17:49                                 ` Florian Schmidt
2004-10-19 15:48                           ` Thomas Gleixner
2004-10-19 16:26                             ` Ingo Molnar
2004-10-19 16:39                               ` Thomas Gleixner
2004-10-19 17:22                         ` Adam Heath
2004-10-19 17:35                           ` Ingo Molnar
2004-10-19 18:52                             ` Adam Heath
2004-10-19 20:59                               ` Lee Revell
2004-10-19 18:00                         ` [patch] Real-Time Preemption, -RT-2.6.9-rc4-mm1-U7 Ingo Molnar
2004-10-19 19:04                           ` Thomas Gleixner
2004-10-19 22:38                             ` Thomas Gleixner
2004-10-19 23:25                             ` Thomas Gleixner
2004-10-19 19:57                           ` Bill Huey
2004-10-23  0:05                             ` Lee Revell
2004-10-19 20:46                           ` Rui Nuno Capela
2004-10-19 21:09                             ` Rui Nuno Capela
2004-10-19 21:30                           ` Rui Nuno Capela
     [not found]                             ` <1098227713.23628.10.camel@krustophenia.net>
     [not found]                               ` <1098228272.12223.1134.camel@thomas>
2004-10-19 23:34                                 ` Lee Revell
2004-10-19 23:38                           ` Fernando Pablo Lopez-Lezcano
2004-10-19 23:39                             ` Thomas Gleixner
2004-10-20  5:02                               ` Thomas Gleixner [this message]
2004-10-20  7:40                                 ` Ingo Molnar
2004-10-20  9:57                                   ` Thomas Gleixner
2004-10-20 10:27                                     ` Ingo Molnar
2004-10-20  5:40                           ` Lee Revell
2004-10-20  9:45                           ` [patch] Real-Time Preemption, -RT-2.6.9-rc4-mm1-U8 Ingo Molnar
2004-10-20 10:04                             ` Ingo Molnar
2004-10-20 10:32                               ` Rui Nuno Capela
2004-10-20 10:40                                 ` Ingo Molnar
2004-10-20 11:31                                   ` Rui Nuno Capela
2004-10-20 11:43                                     ` Ingo Molnar
2004-10-20 12:40                                       ` Rui Nuno Capela
2004-10-20 10:38                             ` Michal Schmidt
2004-10-20 10:56                               ` Ingo Molnar
2004-10-20 11:01                                 ` Michal Schmidt
2004-10-20 12:04                                   ` Ingo Molnar
2004-10-20 21:34                                     ` Michal Schmidt
2004-10-21  8:12                                       ` Ingo Molnar
2004-10-21  8:18                                         ` Ingo Molnar
2004-10-21  8:20                                           ` Ingo Molnar
2004-10-20 12:50                             ` Florian Schmidt
2004-10-20 12:55                               ` Ingo Molnar
2004-10-20 13:25                                 ` Florian Schmidt
2004-10-20 13:24                                   ` Ingo Molnar
2004-10-20 14:24                                   ` Florian Schmidt
2004-10-20 14:18                                     ` Ingo Molnar
2004-10-20 14:53                                       ` Florian Schmidt
2004-10-20 15:08                                         ` Florian Schmidt
2004-10-20 15:37                                       ` Lee Revell
2004-10-20 12:52                             ` Lorenzo Allegrucci
2004-10-20 12:56                               ` Ingo Molnar
2004-10-20 16:27                             ` Adam Heath
2004-10-21 16:59                               ` Adam Heath
2004-10-20 17:49                             ` Alexander Batyrshin
2004-10-20 19:02                               ` Adam Heath
2004-10-20 22:35                               ` Daniel Walker
2004-10-22 13:19                               ` Ingo Molnar
2004-10-22 13:48                               ` Ingo Molnar
2004-10-20 21:19                             ` Esben Nielsen
2004-10-21  0:32                             ` Fernando Pablo Lopez-Lezcano
2004-10-21  9:12                             ` Rui Nuno Capela
2004-10-21  9:16                               ` Thomas Gleixner
2004-10-21  9:35                                 ` Christoph Hellwig
2004-10-21  9:44                                   ` Ingo Molnar
2004-10-21  9:47                                     ` Christoph Hellwig
2004-10-21 10:03                                       ` Ingo Molnar
2004-10-21  9:47                                   ` Thomas Gleixner
2004-10-21  9:53                                 ` Jens Axboe
2004-10-21  9:54                                   ` Thomas Gleixner
2004-10-21 10:11                                     ` Jens Axboe
2004-10-21 10:11                                       ` Thomas Gleixner
2004-10-21 10:42                                         ` Ingo Molnar
2004-10-21 11:59                                           ` john cooper
2004-10-21 14:16                                             ` Esben Nielsen
2004-10-21 14:52                                               ` john cooper
2004-10-21 15:47                                                 ` Eugeny S. Mints
2004-10-21 16:49                                                   ` john cooper
2004-10-21 17:33                                                     ` Scott Wood
2004-10-21 18:09                                                       ` john cooper
2004-10-21 18:47                                                         ` Scott Wood
2004-10-21 20:18                                                           ` john cooper
2004-10-21 21:12                                                             ` Scott Wood
2004-10-21 22:15                                                               ` john cooper
2004-10-21 22:30                                                                 ` Scott Wood
2004-10-21 22:55                                                                   ` john cooper
2004-10-21 21:01                                                           ` Esben Nielsen
2004-10-21 21:52                                                             ` Scott Wood
2004-10-22  0:46                                                             ` john cooper
2004-10-21 18:10                                                       ` Eugeny S. Mints
2004-10-21 18:29                                                         ` Scott Wood
2004-10-21 17:54                                                     ` Eugeny S. Mints
2004-10-21 17:41                                                   ` Scott Wood
2004-10-21 11:11                                         ` Jens Axboe
2004-10-21 11:18                                           ` Thomas Gleixner
2004-10-21 10:18                                       ` Ingo Molnar
2004-10-21 10:34                                         ` Jens Axboe
2004-10-21 19:58                                       ` Bill Huey
2004-10-21 20:14                                         ` Jens Axboe
2004-10-21 20:24                                           ` Bill Huey
2004-10-21 20:33                                             ` Jens Axboe
2004-10-21 20:38                                               ` Bill Huey
2004-10-21 20:43                                                 ` Thomas Gleixner
2004-10-21 23:06                                                   ` Bill Huey
2004-10-22  6:24                                                   ` Jens Axboe
2004-10-21 20:49                                                 ` Bill Huey
2004-10-22  6:19                                                 ` Jens Axboe
2004-10-22  7:29                                                   ` Ingo Molnar
2004-10-22  8:01                                                     ` Jens Axboe
2004-10-22  8:13                                                       ` Ingo Molnar
2004-10-22  8:50                                                   ` Bill Huey
2004-10-22  8:59                                                     ` Jens Axboe
2004-10-22  9:06                                                       ` Bill Huey
2004-10-22  9:09                                                         ` Bill Huey
2004-10-22  9:20                                                           ` Jens Axboe
2004-10-22  9:24                                                             ` Bill Huey
2004-10-22  9:31                                                               ` Jens Axboe
2004-10-22  9:17                                                         ` Jens Axboe
2004-10-22  9:23                                                         ` Thomas Gleixner
2004-10-22  9:00                                                     ` Ingo Molnar
2004-10-22 10:21                                                     ` Christoph Hellwig
2004-10-21 22:42                                             ` Timothy Miller
2004-10-21 23:01                                               ` Thomas Gleixner
2004-10-21  9:18                               ` Ingo Molnar
2004-10-21 10:26                                 ` Rui Nuno Capela
2004-10-21 11:20                                   ` Rui Nuno Capela
2004-10-21  9:55                               ` Thomas Gleixner
2004-10-21 13:03                               ` Rui Nuno Capela
2004-10-21 13:41                                 ` Ingo Molnar
2004-10-21 13:53                                   ` Ingo Molnar
2004-10-22 10:15                                 ` Rui Nuno Capela
2004-10-21 13:27                             ` [patch] Real-Time Preemption, -RT-2.6.9-rc4-mm1-U9 Ingo Molnar
2004-10-21 14:22                               ` Thomas Gleixner
2004-10-21 14:43                                 ` Thomas Gleixner
2004-10-21 15:41                               ` [patch] Real-Time Preemption, -RT-2.6.9-rc4-mm1-U9 HOTFIX Thomas Gleixner
2004-10-21 15:58                                 ` Ingo Molnar
2004-10-21 15:43                               ` [patch] Real-Time Preemption, -RT-2.6.9-rc4-mm1-U9 Michal Schmidt
2004-10-21 16:00                                 ` Ingo Molnar
2004-10-21 18:06                               ` Gunther Persoons
2004-10-21 16:40                                 ` Ingo Molnar
2004-10-21 17:54                                   ` Nikita Danilov
2004-10-22 10:22                                     ` Ingo Molnar
2004-10-22 11:50                                       ` Nikita Danilov
2004-10-22 11:57                                         ` Ingo Molnar
2004-10-22 12:27                                           ` Nikita Danilov
2004-10-22 12:42                                             ` Ingo Molnar
2004-10-21 20:21                                   ` Gunther Persoons
2004-10-21 18:07                               ` K.R. Foley
2004-10-21 18:40                                 ` Thomas Gleixner
2004-10-21 18:57                                   ` K.R. Foley
2004-10-21 18:57                                     ` Thomas Gleixner
2004-10-21 19:25                                       ` K.R. Foley
2004-10-22 14:12                                       ` K.R. Foley
2004-10-22 14:43                                         ` Thomas Gleixner
2004-10-22 15:15                                           ` K.R. Foley
2004-10-22 15:57                                             ` Thomas Gleixner
2004-10-22 16:51                                               ` Ingo Molnar
2004-10-22 17:44                                               ` K.R. Foley
2004-10-21 19:09                                   ` K.R. Foley
2004-10-22 11:54                                 ` Ingo Molnar
2004-10-21 18:34                               ` Adam Heath
2004-10-21 20:06                               ` Michal Schmidt
2004-10-22 13:35                               ` [patch] Real-Time Preemption, -RT-2.6.9-rc4-mm1-U9.3 Ingo Molnar
2004-10-22 15:50                                 ` [patch] Real-Time Preemption, -RT-2.6.9-mm1-U10 Ingo Molnar
2004-10-22 16:47                                   ` Gene Heskett
2004-10-22 16:51                                     ` Ingo Molnar
2004-10-22 16:19                                       ` Jeff V. Merkey
2004-10-22 17:27                                         ` Russell Miller
2004-10-22 16:48                                           ` Jeff V. Merkey
2004-10-22 21:47                                         ` Gene Heskett
2004-10-22 17:56                                   ` [patch] Real-Time Preemption, -RT-2.6.9-mm1-U10.2 Ingo Molnar
2004-10-22 21:49                                     ` Gene Heskett
2004-10-22 22:06                                       ` Lee Revell
2004-10-22 22:30                                         ` Lee Revell
2004-10-23 10:36                                         ` Ingo Molnar
2004-10-25  0:33                                           ` john cooper
2004-10-25 10:09                                             ` remi.colinet
2004-10-25 13:35                                               ` john cooper
2004-10-22 22:38                                     ` K.R. Foley
2004-10-23 10:32                                       ` Ingo Molnar
2004-10-23 14:03                                         ` K.R. Foley
2004-10-23  0:27                                     ` Rui Nuno Capela
2004-10-23  0:41                                       ` Fernando Pablo Lopez-Lezcano
2004-10-23 10:29                                       ` Ingo Molnar
2004-10-23 12:30                                         ` Rui Nuno Capela
2004-10-23 12:51                                           ` Ingo Molnar
2004-10-23 13:45                                             ` Rui Nuno Capela
2004-10-23 13:54                                               ` Ingo Molnar
2004-10-23 20:59                                                 ` Rui Nuno Capela
2004-10-23  1:15                                     ` [patch] Real-Time Preemption, -RT-2.6.9-mm1-U10.3 Thomas Gleixner
2004-10-23 18:51                                     ` [patch] Real-Time Preemption, -RT-2.6.9-mm1-U10.2 Paul E. McKenney
2004-10-23 19:14                                       ` Lee Revell
2004-10-23 19:31                                         ` Thomas Gleixner
2004-10-23 20:24                                       ` Ingo Molnar
2004-10-23 21:12                                         ` Paul E. McKenney
2004-10-24 15:19                                     ` Gunther Persoons
2004-10-25 10:40                                     ` [patch] Real-Time Preemption, -RT-2.6.9-mm1-V0 Ingo Molnar
2004-10-25 11:08                                       ` K.R. Foley
2004-10-25 11:10                                         ` Ingo Molnar
2004-10-25 11:13                                           ` K.R. Foley
2004-10-25 12:12                                           ` Ingo Molnar
2004-10-25 13:24                                             ` Florian Schmidt
2004-10-25 13:26                                               ` Ingo Molnar
2004-10-25 14:03                                                 ` Florian Schmidt
2004-10-25 14:10                                                   ` Ingo Molnar
2004-10-25 14:16                                                     ` Ingo Molnar
2004-10-25 19:40                                                       ` Rui Nuno Capela
2004-10-26  3:01                                                         ` Lee Revell
2004-10-26  3:11                                                           ` K.R. Foley
2004-10-26  3:58                                                             ` Lee Revell
2004-10-26  4:15                                                               ` K.R. Foley
2004-10-26  5:11                                                           ` Fernando Pablo Lopez-Lezcano
2004-10-26 17:25                                                             ` Lee Revell
2004-10-26 17:45                                                               ` Fernando Pablo Lopez-Lezcano
2004-10-26 17:55                                                                 ` Lee Revell
2004-10-26  5:28                                                         ` Denis Vlasenko
2004-10-26 10:40                                                           ` Rui Nuno Capela
2004-10-26 19:09                                                             ` Denis Vlasenko
2004-10-27  8:23                                                               ` Rui Nuno Capela
2004-10-25 15:06                                                     ` Florian Schmidt
2004-10-25 16:45                                                       ` K.R. Foley
2004-10-26  8:29                                                         ` Eran Mann
2004-10-25 13:39                                             ` Florian Schmidt
2004-10-25 13:48                                               ` Florian Schmidt
2004-10-25 13:35                                                 ` Ingo Molnar
2004-10-25 18:52                                       ` K.R. Foley
2004-10-25 20:38                                         ` Ingo Molnar
2004-10-26 10:53                                           ` K.R. Foley
2004-10-26 10:57                                             ` Ingo Molnar
2004-10-27  0:24                                             ` Ingo Molnar
2004-10-27  0:53                                               ` K.R. Foley
2004-10-27  3:32                                               ` K.R. Foley
2004-10-27  8:28                                                 ` Ingo Molnar
2004-10-27  8:44                                                   ` Ingo Molnar
2004-10-27  8:52                                                     ` Ingo Molnar
2004-10-27  9:06                                                       ` Ingo Molnar
2004-10-27 10:03                                                         ` Ingo Molnar
2004-10-27 10:33                                                         ` Florian Schmidt
2004-10-27 10:29                                                           ` Ingo Molnar
2004-10-27 10:58                                                             ` Florian Schmidt
2004-10-27 10:45                                                           ` Florian Schmidt
2004-10-27 11:09                                                             ` Ingo Molnar
2004-10-27  9:24                                                 ` Ingo Molnar
2004-10-27  9:32                                                   ` Ingo Molnar
2004-10-27 12:19                                                     ` K.R. Foley
2004-10-27 13:29                                                 ` Ingo Molnar
2004-10-27 15:00                                                   ` K.R. Foley
2004-10-27 15:05                                                     ` Ingo Molnar
2004-10-27 15:13                                                       ` Lee Revell
2004-10-27 15:17                                                         ` Ingo Molnar
2004-10-27 17:14                                                           ` Lee Revell
2004-10-27 17:21                                                             ` K.R. Foley
2004-10-27 17:26                                                               ` Lee Revell
2004-10-27 17:40                                                                 ` K.R. Foley
2004-10-27 17:44                                                                   ` Lee Revell
2004-10-27 17:43                                                                 ` K.R. Foley
2004-10-27 19:47                                                                   ` Lee Revell
2004-10-27 21:40                                                                     ` K.R. Foley
2004-10-27 20:09                                                           ` Andrew Morton
2004-10-27 21:43                                                             ` K.R. Foley
2004-10-27 15:16                                                       ` K.R. Foley
2004-10-27 20:49                                                       ` Bill Huey
2004-10-27 20:54                                                         ` Bill Huey
2004-10-27 21:01                                                           ` Bill Huey
2004-10-28  7:11                                                             ` Ingo Molnar
2004-10-27  3:48                                               ` K.R. Foley
2004-10-25 21:41                                         ` Esben Nielsen
2004-10-25 21:47                                       ` Michal Schmidt
2004-10-25 23:04                                       ` Remi Colinet
2004-10-27  0:15                                       ` [patch] Real-Time Preemption, -RT-2.6.9-mm1-V0.3 Ingo Molnar
2004-10-27  0:44                                         ` Ingo Molnar
2004-10-27  1:43                                         ` Bill Huey
2004-10-27  2:04                                           ` K.R. Foley
2004-10-27  3:29                                             ` Bill Huey
2004-10-27  3:35                                               ` K.R. Foley
2004-10-27  3:40                                                 ` Bill Huey
2004-10-27 10:50                                         ` Michal Schmidt
2004-10-27 13:48                                           ` Ingo Molnar
2004-10-27 17:25                                             ` Michal Schmidt
2004-10-28 11:57                                               ` [patch] Real-Time Preemption, -RT-2.6.9-mm1-V0.5 Ingo Molnar
2004-10-30  0:02                                                 ` Bill Huey
2004-10-30 11:46                                                   ` Ingo Molnar
2004-11-02  8:56                                                   ` [patch] Real-Time Preemption, -RT-2.6.9-mm1-V0.5 (networking problems) Bill Huey
2004-11-02  9:37                                                     ` Ingo Molnar
2004-11-02 11:08                                                       ` Bill Huey
2004-11-02 11:45                                                         ` Ingo Molnar
2004-11-02 12:02                                                           ` Ingo Molnar
2004-11-02 17:34                                                             ` Karsten Wiese
2004-11-02 13:35                                                           ` Ingo Molnar
2004-11-02 22:08                                                           ` Bill Huey
2004-10-27 12:43                                         ` [patch] Real-Time Preemption, -RT-2.6.9-mm1-V0.3 Rui Nuno Capela
2004-10-27 13:53                                           ` Ingo Molnar
2004-10-27 15:26                                             ` [patch] Real-Time Preemption, -RT-2.6.9-mm1-V0.4 Rui Nuno Capela
2004-10-27 15:30                                               ` Lee Revell
2004-10-27 17:39                                                 ` Rui Nuno Capela
2004-10-27 18:57                                                   ` karsten wiese
2004-10-27 20:28                                                     ` Rui Nuno Capela
2004-10-27 18:59                                                   ` karsten wiese
2004-10-27 20:01                                               ` Ingo Molnar
2004-10-27 20:51                                               ` Ingo Molnar
2004-10-27 21:19                                                 ` Ingo Molnar
2004-10-27 23:31                                                   ` Rui Nuno Capela
2004-10-28  6:36                                                     ` Ingo Molnar
2004-10-28  8:31                                                       ` Rui Nuno Capela
2004-10-28  8:56                                                         ` Ingo Molnar
2004-10-28  9:17                                                           ` Rui Nuno Capela
2004-10-28  9:32                                                             ` Ingo Molnar
2004-10-28 13:57                                                               ` [patch] Real-Time Preemption, -RT-2.6.9-mm1-V0.5.2 Ingo Molnar
2004-10-28 14:10                                                                 ` DaMouse
2004-10-28 14:18                                                                   ` Ingo Molnar
2004-10-28 16:33                                                               ` [patch] Real-Time Preemption, -RT-2.6.9-mm1-V0.4 Rui Nuno Capela
2004-10-28 19:16                                                                 ` Ingo Molnar
2004-10-28 23:49                                                                   ` Rui Nuno Capela
2004-10-29  0:07                                                                     ` Lee Revell
2004-10-29  7:30                                                                     ` Ingo Molnar
2004-10-29 15:00                                                                       ` Rui Nuno Capela
2004-10-29 17:57                                                                         ` Lee Revell
2004-10-29 14:31                                                                 ` Florian Schmidt
2004-10-29 14:25                                                                   ` Ingo Molnar
2004-10-29 15:09                                                                     ` Florian Schmidt
2004-10-29 14:53                                                                   ` Florian Schmidt
2004-10-30  3:09                                                                   ` Lee Revell
2004-10-30  3:22                                                                     ` Joe
2004-10-27 13:03                                         ` Ingo Molnar
2004-10-27 21:41                                           ` Magnus Naeslund(t)
2004-10-28  6:55                                             ` Ingo Molnar
2004-10-28  9:31                                               ` Magnus Naeslund(t)
2004-10-28  6:58                                             ` Ingo Molnar
2004-10-28 14:14                                           ` K.R. Foley
2004-10-28 14:20                                             ` Ingo Molnar
2004-11-03 10:58                                         ` [patch] Real-Time Preemption, -RT-2.6.10-rc1-mm2-V0.7.1 Ingo Molnar
2004-11-03 13:44                                           ` Lorenzo Allegrucci
2004-11-03 13:46                                             ` Ingo Molnar
2004-11-03 17:53                                               ` Lorenzo Allegrucci
2004-11-03 20:41                                                 ` Lorenzo Allegrucci
2004-11-03 20:43                                                   ` Ingo Molnar
2004-11-03 21:05                                                     ` Lorenzo Allegrucci
2004-11-03 19:33                                           ` john cooper
2004-11-03 23:03                                           ` Magnus Naeslund(t)
2004-11-04  6:56                                             ` Ingo Molnar
2004-11-04 19:34                                           ` Gunther Persoons
2004-11-04 20:31                                             ` Chris Friesen
2004-11-06 15:57                                           ` [patch] Real-Time Preemption, -RT-2.6.10-rc1-mm3-V0.7.18 Ingo Molnar
2004-11-06 17:17                                             ` Gunther Persoons
2004-11-06 19:25                                               ` Lorenzo Allegrucci
2004-11-06 17:55                                             ` Rui Nuno Capela
2004-11-06 18:56                                               ` Peter Zijlstra
2004-11-06 22:52                                             ` Rui Nuno Capela
2004-11-07 22:22                                             ` Karsten Wiese
2004-11-08  8:21                                               ` Ingo Molnar
2004-11-08  7:50                                             ` Eran Mann
2004-11-08  9:45                                               ` Ingo Molnar
2004-11-08  9:16                                             ` [patch] Real-Time Preemption, -RT-2.6.10-rc1-mm3-V0.7.19 Ingo Molnar
2004-11-08  9:15                                               ` Karsten Wiese
2004-11-08 10:19                                                 ` Ingo Molnar
2004-11-08 12:42                                                   ` Karsten Wiese
2004-11-08 10:24                                                 ` Ingo Molnar
2004-11-08  9:50                                               ` [patch] Real-Time Preemption, -RT-2.6.10-rc1-mm3-V0.7.20 Ingo Molnar
2004-11-08 13:13                                                 ` Lorenzo Allegrucci
2004-11-08 14:15                                                 ` Rui Nuno Capela
2004-11-08 16:17                                                 ` Florian Schmidt
2004-11-08 16:57                                               ` [patch] Real-Time Preemption, -RT-2.6.10-rc1-mm3-V0.7.21 Ingo Molnar
2004-11-08 17:41                                                 ` Gunther Persoons
2004-11-08 23:41                                                   ` Ingo Molnar
2004-11-08 17:59                                                 ` Norberto Bensa
2004-11-08 19:01                                                   ` K.R. Foley
2004-11-08 23:42                                                     ` Ingo Molnar
2004-11-09 16:05                                                 ` [patch] Real-Time Preemption, -RT-2.6.10-rc1-mm3-V0.7.23 Ingo Molnar
2004-11-10 13:52                                                   ` Karsten Wiese
2004-11-10 13:58                                                     ` Karsten Wiese
2004-11-10 15:01                                                     ` Ingo Molnar
2004-11-10 14:20                                                       ` Karsten Wiese
2004-11-10 14:50                                                         ` Karsten Wiese
2004-11-10 15:33                                                         ` Ingo Molnar
2004-11-11  4:34                                                   ` K.R. Foley
2004-11-11  5:01                                                   ` K.R. Foley
2004-11-11  9:52                                                     ` Ingo Molnar
2004-11-11 10:20                                                     ` Ingo Molnar
2004-11-11 13:05                                                       ` Ingo Molnar
2004-11-11 12:27                                                         ` K.R. Foley
2004-11-11 14:44                                                   ` [patch] Real-Time Preemption, -RT-2.6.10-rc1-mm3-V0.7.25-0 Ingo Molnar
2004-11-11 16:03                                                     ` Gunther Persoons
2004-11-11 16:08                                                       ` Ingo Molnar
2004-11-11 16:12                                                         ` Ingo Molnar
2004-11-11 16:25                                                           ` Gunther Persoons
2004-11-11 16:30                                                           ` Ingo Molnar
2004-11-11 17:36                                                             ` Gunther Persoons
2004-11-11 16:16                                                         ` Gunther Persoons
2004-11-11 20:56                                                     ` Remi Colinet
2004-11-11 18:12                                                       ` K.R. Foley
2004-11-11 18:42                                                       ` K.R. Foley
2004-11-11 21:41                                                         ` Ingo Molnar
2004-11-12  3:49                                                         ` Remi Colinet
2004-11-11 21:38                                                     ` Ingo Molnar
2004-11-11 21:51                                                     ` [patch] Real-Time Preemption, -RT-2.6.10-rc1-mm3-V0.7.25-1 Ingo Molnar
2004-11-12  4:08                                                       ` Bill Huey
2004-11-12  5:03                                                         ` Bill Huey
2004-11-12  8:39                                                           ` Ingo Molnar
2004-11-12 10:52                                                             ` Bill Huey
2004-11-12 14:31                                                       ` Shane Shrybman
2004-11-12 17:27                                                         ` K.R. Foley
2004-11-12 17:50                                                           ` Shane Shrybman
2004-11-12 20:13                                                         ` Ingo Molnar
2004-11-12 22:15                                                           ` Shane Shrybman
2004-11-12 23:44                                                           ` Shane Shrybman
2004-11-14 12:51                                                             ` Ingo Molnar
2004-11-12 19:48                                                       ` Gunther Persoons
2004-11-12 20:19                                                         ` Ingo Molnar
2004-11-13 12:55                                                           ` Gunther Persoons
2004-11-13 14:36                                                           ` Gunther Persoons
2004-11-14 12:49                                                             ` Ingo Molnar
2004-11-14 14:25                                                               ` Gunther Persoons
2004-11-13 23:12                                                           ` Gunther Persoons
2004-11-14 12:38                                                             ` Ingo Molnar
2004-11-14 12:56                                                       ` Florian Schmidt
2004-11-14 13:26                                                         ` K.R. Foley
2004-11-14 13:35                                                           ` Florian Schmidt
2004-11-14 13:56                                                           ` K.R. Foley
2004-11-14 14:11                                                           ` Florian Schmidt
2004-11-14 14:15                                                         ` Ingo Molnar
2004-11-15  1:27                                                           ` Florian Schmidt
2004-11-15  2:22                                                             ` K.R. Foley
2004-11-15 15:15                                                           ` Florian Schmidt
2004-11-15 14:33                                                       ` Rui Nuno Capela
2004-11-15 15:40                                                         ` Ingo Molnar
2004-11-15 16:11                                                         ` Ingo Molnar
2004-11-15 16:52                                                           ` Rui Nuno Capela
     [not found]                                                           ` <33583.195.245.190.93.1100537554.squirrel@195.245.190.93>
2004-11-15 22:35                                                             ` Rui Nuno Capela
2004-11-16 10:41                                                               ` Ingo Molnar
2004-11-16 12:05                                                                 ` Rui Nuno Capela
2004-11-16 13:16                                                                 ` [patch] Real-Time Preemption, -RT-2.6.10-rc2-mm1-V0.7.27-2 Ingo Molnar
2004-11-16 12:54                                                       ` [patch] Real-Time Preemption, -RT-2.6.10-rc2-mm1-V0.7.27-0 Ingo Molnar
2004-11-16 13:09                                                         ` [patch] Real-Time Preemption, -RT-2.6.10-rc2-mm1-V0.7.27-1 Ingo Molnar
2004-11-16 13:40                                                           ` [patch] Real-Time Preemption, -RT-2.6.10-rc2-mm1-V0.7.27-3 Ingo Molnar
2004-11-16 14:20                                                             ` Florian Schmidt
2004-11-16 15:08                                                               ` Florian Schmidt
2004-11-16 15:29                                                                 ` Florian Schmidt
2004-11-16 15:52                                                                   ` Stefan Schweizer
2004-11-16 18:43                                                             ` Marcos D. Marado Torres
2004-11-16 18:51                                                               ` Lee Revell
2004-11-16 19:53                                                               ` Ingo Molnar
2004-11-17  0:36                                                             ` Bill Huey
2004-11-17 12:42                                                             ` [patch] Real-Time Preemption, -RT-2.6.10-rc2-mm1-V0.7.28-0 Ingo Molnar
2004-11-17 18:18                                                               ` [patch] Real-Time Preemption, -RT-2.6.10-rc2-mm1-V0.7.27-10 Adam Heath
2004-11-18 15:44                                                                 ` Ingo Molnar
2004-11-18  2:38                                                               ` [patch] Real-Time Preemption, -RT-2.6.10-rc2-mm1-V0.7.28-0 K.R. Foley
2004-11-18  9:57                                                                 ` Ingo Molnar
2004-11-18 10:24                                                               ` Christian Meder
2004-11-18 16:11                                                                 ` Ingo Molnar
2004-11-18 15:58                                                                   ` Christian Meder
2004-11-18 16:39                                                                   ` Christian Meder
2004-11-18 19:58                                                                     ` Ingo Molnar
2004-11-18 19:51                                                                       ` Adam Heath
2004-11-18 12:35                                                               ` [patch] Real-Time Preemption, -RT-2.6.10-rc2-mm1-V0.7.28-1 Ingo Molnar
2004-11-18 12:23                                                                 ` Florian Schmidt
2004-11-18 14:46                                                                 ` Rui Nuno Capela
2004-11-18 20:01                                                                   ` Ingo Molnar
2004-11-18 20:49                                                                   ` Ingo Molnar
2004-11-18 21:05                                                                   ` Ingo Molnar
2004-11-18 22:54                                                                     ` Christian Meder
2004-11-19  9:54                                                                       ` Ingo Molnar
2004-11-22  9:31                                                                         ` Christian Meder
2004-11-22  9:44                                                                           ` Bill Huey
2004-11-22 13:19                                                                             ` Ingo Molnar
2004-11-22 13:05                                                                           ` Ingo Molnar
2004-11-22 13:32                                                                             ` Christian Meder
2004-11-22 14:38                                                                               ` Ingo Molnar
2004-11-18 21:50                                                                   ` Lee Revell
2004-11-19  9:56                                                                     ` Ingo Molnar
2004-11-19 15:44                                                                       ` Shane Shrybman
2004-11-20 13:17                                                                         ` Ingo Molnar
2004-11-18 15:23                                                                 ` Christian Meder
2004-11-18 15:37                                                                   ` Jan Engelhardt
2004-11-18 20:06                                                                   ` [patch] " Ingo Molnar
2004-11-18 16:46                                                                 ` [patch] Real-Time Preemption, -RT-2.6.10-rc2-mm2-V0.7.29-0 Ingo Molnar
2004-11-18 21:27                                                                   ` Michal Schmidt
2004-11-19 10:05                                                                     ` Ingo Molnar
2004-11-19 14:11                                                                       ` Steven Rostedt
2004-11-19 17:08                                                                         ` K.R. Foley
2004-11-21 21:50                                                                           ` Ingo Molnar
2004-11-19 19:05                                                                   ` Peter Zijlstra
2004-11-20 13:13                                                                     ` Ingo Molnar
2004-11-20  3:22                                                                   ` Lee Revell
2004-11-20 11:50                                                                     ` Florian Schmidt
2004-11-20 12:59                                                                       ` Ingo Molnar
2004-11-20 12:55                                                                     ` Ingo Molnar
2004-11-20 17:19                                                                       ` Lee Revell
2004-11-20 19:14                                                                         ` Ingo Molnar
2004-11-20 18:35                                                                           ` Lee Revell
2004-11-20 19:11                                                                             ` Florian Schmidt
2004-11-20 20:40                                                                               ` Florian Schmidt
2004-11-21 12:45                                                                                 ` Ingo Molnar
2004-11-21 14:32                                                                                   ` Ingo Molnar
2004-11-21 14:49                                                                                   ` Florian Schmidt
2004-11-21 12:50                                                                                 ` Ingo Molnar
2004-11-21 14:50                                                                                   ` Florian Schmidt
2004-11-21 12:54                                                                                 ` Ingo Molnar
2004-11-21 13:43                                                                                   ` Ingo Molnar
2004-11-21 15:05                                                                                     ` Florian Schmidt
2004-11-21 14:52                                                                                   ` Florian Schmidt
2004-11-21 15:12                                                                               ` Ingo Molnar
2004-11-21 15:18                                                                                 ` Ingo Molnar
2004-11-21 14:44                                                                                   ` Florian Schmidt
2004-11-21 15:28                                                                                 ` Florian Schmidt
2004-11-20 19:09                                                                           ` Lee Revell
2004-11-21 12:47                                                                             ` Ingo Molnar
2004-11-21 13:27                                                                               ` Ingo Molnar
2004-11-21 13:32                                                                                 ` Ingo Molnar
2004-11-21  0:32                                                                           ` Lee Revell
2004-11-24 12:15                                                                             ` [patch] Real-Time Preemption, -RT-2.6.10-rc2-mm3-V0.7.31-1 Ingo Molnar
2004-11-24 12:28                                                                               ` [patch] Real-Time Preemption, -RT-2.6.10-rc2-mm3-V0.7.31-2 Ingo Molnar
2004-11-20 20:23                                                                   ` [patch] Real-Time Preemption, -RT-2.6.10-rc2-mm2-V0.7.29-0 K.R. Foley
2004-11-20 20:51                                                                     ` K.R. Foley
2004-11-22  0:54                                                                   ` [patch] Real-Time Preemption, -RT-2.6.10-rc2-mm2-V0.7.30-2 Ingo Molnar
2004-11-22  1:07                                                                     ` Florian Schmidt
2004-11-22  9:46                                                                       ` Ingo Molnar
2004-11-22 10:36                                                                         ` Rui Nuno Capela
2004-11-22 13:24                                                                           ` Ingo Molnar
2004-11-22 12:56                                                                             ` Rui Nuno Capela
2004-11-22 15:00                                                                               ` Ingo Molnar
2004-11-22 15:10                                                                                 ` Ingo Molnar
2004-11-22 15:20                                                                                   ` Ingo Molnar
2004-11-22 13:27                                                                             ` Florian Schmidt
2004-11-22 14:18                                                                               ` Rui Nuno Capela
2004-11-22 15:41                                                                                 ` Ingo Molnar
2004-11-22 15:45                                                                                 ` Ingo Molnar
2004-11-22 16:53                                                                                   ` Rui Nuno Capela
2004-11-23 13:55                                                                                     ` Ingo Molnar
2004-11-23 13:56                                                                                       ` Ingo Molnar
2004-11-23 13:58                                                                                       ` Ingo Molnar
2004-11-23 14:11                                                                                         ` Ingo Molnar
2004-11-23 14:32                                                                                           ` Ingo Molnar
2004-11-23 14:41                                                                                             ` Ingo Molnar
2004-11-23 14:00                                                                                       ` Rui Nuno Capela
2004-11-23 15:41                                                                                         ` Ingo Molnar
2004-11-23 16:53                                                                                           ` Rui Nuno Capela
2004-11-23 18:00                                                                                             ` Ingo Molnar
2004-11-23 14:46                                                                                     ` Ingo Molnar
2004-11-23 13:57                                                                                       ` Florian Schmidt
2004-11-23 15:05                                                                                         ` Ingo Molnar
2004-11-23 15:21                                                                                         ` Ingo Molnar
2004-11-23 14:41                                                                                           ` Florian Schmidt
2004-12-01 13:57                                                                                             ` Paul Davis
2004-12-01 14:37                                                                                               ` Ingo Molnar
2004-12-01 14:56                                                                                                 ` Paul Davis
2004-12-01 15:53                                                                                                   ` Ingo Molnar
2004-12-01 16:05                                                                                                     ` Paul Davis
2004-12-01 16:16                                                                                                     ` Esben Nielsen
2004-12-01 21:24                                                                                                       ` Ingo Molnar
2004-12-01 21:40                                                                                                         ` Chris Friesen
2004-12-01 16:08                                                                                                   ` Esben Nielsen
2004-11-23 14:53                                                                                       ` Ingo Molnar
2004-11-22  8:44                                                                     ` Eran Mann
2004-11-22 10:01                                                                       ` Ingo Molnar
2004-11-22 13:34                                                                         ` Eran Mann
2004-11-22 14:42                                                                           ` Ingo Molnar
2004-11-23  8:24                                                                             ` Eran Mann
2004-11-23 17:58                                                                     ` [patch] Real-Time Preemption, -RT-2.6.10-rc2-mm2-V0.7.30-9 Ingo Molnar
2004-11-23 17:53                                                                       ` K.R. Foley
2004-11-23 18:01                                                                       ` K.R. Foley
2004-11-24  0:28                                                                       ` Florian Schmidt
2004-11-24  3:19                                                                         ` Ingo Molnar
2004-11-24  2:48                                                                           ` Florian Schmidt
2004-11-24  0:58                                                                       ` Lee Revell
2004-11-24  3:45                                                                         ` Ingo Molnar
2004-11-24 13:33                                                                           ` Steven Rostedt
2004-11-24 15:23                                                                             ` kernel builds starving evolution process - scheduler issue? (was Re: [patch] Real-Time Preemption, -RT-2.6.10-rc2-mm2-V0.7.30-9) Lee Revell
2004-11-24 10:16                                                                       ` [patch] Real-Time Preemption, -RT-2.6.10-rc2-mm2-V0.7.30-10 Ingo Molnar
2004-11-24 11:27                                                                         ` [patch] Real-Time Preemption, -RT-2.6.10-rc2-mm3-V0.7.31-0 Ingo Molnar
2004-11-24 19:43                                                                           ` Gene Heskett
2004-11-25 10:03                                                                           ` Rui Nuno Capela
2004-11-25 11:13                                                                             ` Ingo Molnar
2004-11-25 10:38                                                                               ` Rui Nuno Capela
2004-11-25 11:44                                                                                 ` Ingo Molnar
2004-11-25 10:47                                                                                   ` Rui Nuno Capela
2004-11-25 11:17                                                                               ` Ingo Molnar
2004-11-25 12:01                                                                             ` Ingo Molnar
2004-11-25 11:14                                                                               ` Rui Nuno Capela
2004-11-25 12:20                                                                                 ` Ingo Molnar
2004-11-25 14:33                                                                               ` [patch, 2.6.10-rc2] floppy boot-time detection fix Ingo Molnar
2004-11-25 14:44                                                                                 ` Ingo Molnar
2004-11-25 14:48                                                                                 ` Ingo Molnar
2004-11-25 15:27                                                                                   ` Ingo Molnar
2004-11-25 15:00                                                                                 ` Arjan van de Ven
2004-12-03 20:58                                                                         ` [patch] Real-Time Preemption, -RT-2.6.10-rc2-mm2-V0.7.32-0 Ingo Molnar
2004-12-03 21:04                                                                           ` Ingo Molnar
2004-12-04 22:32                                                                           ` Rui Nuno Capela
2004-12-04 22:46                                                                             ` Ingo Molnar
2004-12-04 23:38                                                                               ` Rui Nuno Capela
2004-12-04 23:55                                                                               ` K.R. Foley
2004-12-05  3:10                                                                                 ` Gene Heskett
2004-12-05  3:05                                                                             ` Gene Heskett
2004-12-05 23:14                                                                           ` Esben Nielsen
2004-12-06 13:14                                                                             ` Ingo Molnar
2004-12-06 15:01                                                                               ` Esben Nielsen
2004-12-06 15:27                                                                                 ` Ingo Molnar
2004-12-07 13:29                                                                           ` [patch] Real-Time Preemption, -RT-2.6.10-rc2-mm3-V0.7.32-4 Ingo Molnar
2004-12-07 14:11                                                                             ` [patch] Real-Time Preemption, -RT-2.6.10-rc2-mm3-V0.7.32-6 Ingo Molnar
2004-12-08  4:31                                                                               ` K.R. Foley
2004-12-08  8:34                                                                                 ` Ingo Molnar
2004-12-08 16:07                                                                                   ` K.R. Foley
2004-12-08 16:18                                                                                     ` Lee Revell
2004-12-08 16:52                                                                                       ` K.R. Foley
2004-12-08 16:58                                                                                         ` Lee Revell
2004-12-09  9:02                                                                                         ` Ingo Molnar
2004-12-09  2:45                                                                                     ` K.R. Foley
2004-12-09 12:11                                                                                       ` Ingo Molnar
2004-12-09 14:50                                                                                         ` K.R. Foley
2004-12-08 17:13                                                                               ` Steven Rostedt
2004-12-08 18:14                                                                                 ` Rui Nuno Capela
2004-12-08 19:03                                                                                   ` Steven Rostedt
2004-12-08 21:39                                                                                     ` Rui Nuno Capela
2004-12-08 22:11                                                                                       ` Steven Rostedt
2004-12-09  9:32                                                                                         ` Ingo Molnar
2004-12-09 13:13                                                                                           ` [patch] Real-Time Preemption, -RT-2.6.10-rc2-mm3-V0.7.32-12 Ingo Molnar
2004-12-09 14:23                                                                                             ` Gene Heskett
2004-12-09 14:33                                                                                             ` Steven Rostedt
2004-12-09 19:19                                                                                               ` Steven Rostedt
2004-12-09 20:33                                                                                                 ` john cooper
2004-12-09 22:19                                                                                                   ` Steven Rostedt
2004-12-09 23:10                                                                                                     ` john cooper
2004-12-09 22:10                                                                                                 ` Ingo Molnar
2004-12-10  6:11                                                                                                   ` Steven Rostedt
2004-12-10 11:05                                                                                                     ` Ingo Molnar
2004-12-10 11:11                                                                                                     ` Ingo Molnar
2004-12-10 16:32                                                                                                       ` K.R. Foley
2004-12-10 18:02                                                                                                         ` Steven Rostedt
2004-12-11  2:26                                                                                                       ` Steven Rostedt
2004-12-11  3:01                                                                                                         ` Steven Rostedt
2004-12-11  7:37                                                                                                         ` Fernando Lopez-Lezcano
2004-12-11 12:30                                                                                                           ` Steven Rostedt
2004-12-13 23:34                                                                                                             ` Fernando Lopez-Lezcano
2004-12-15  9:51                                                                                                               ` Ingo Molnar
2004-12-11  9:57                                                                                                         ` Ingo Molnar
2004-12-09 14:43                                                                                             ` Rui Nuno Capela
2004-12-09 13:36                                                                                           ` [patch] Real-Time Preemption, -RT-2.6.10-rc2-mm3-V0.7.32-6 Steven Rostedt
2004-12-09  9:06                                                                                 ` Ingo Molnar
2004-12-14 13:28                                                                               ` [patch] Real-Time Preemption, -RT-2.6.10-rc3-mm1-V0.7.33-0 Ingo Molnar
2004-12-14 19:34                                                                                 ` Steven Rostedt
2004-12-14 20:08                                                                                   ` Lee Revell
2004-12-14 20:45                                                                                     ` Steven Rostedt
2004-12-14 21:18                                                                                       ` Ingo Molnar
2004-12-14 21:47                                                                                         ` Lee Revell
2004-12-14 21:51                                                                                           ` Ingo Molnar
2004-12-14 21:57                                                                                             ` Lee Revell
2004-12-14 21:52                                                                                         ` George Anzinger
2004-12-14 21:59                                                                                           ` Steven Rostedt
2004-12-14 22:28                                                                                           ` Ingo Molnar
2004-12-14 22:13                                                                                         ` Lee Revell
2004-12-14 22:31                                                                                           ` Ingo Molnar
2004-12-14 22:47                                                                                             ` Lee Revell
2004-12-14 22:57                                                                                               ` Paul Davis
2004-12-15  9:32                                                                                                 ` Ingo Molnar
2004-12-15 16:23                                                                                                   ` Lee Revell
2004-12-14 23:18                                                                                               ` linux-os
2004-12-15  1:53                                                                                                 ` Paul Davis
2004-12-15  2:49                                                                                                 ` Gene Heskett
2004-12-15  2:38                                                                                             ` Gene Heskett
2004-12-15 15:24                                                                                               ` K.R. Foley
2004-12-15 16:34                                                                                                 ` Gene Heskett
2004-12-15 16:38                                                                                                   ` K.R. Foley
2004-12-14 20:07                                                                                 ` Fernando Lopez-Lezcano
2004-12-14 20:35                                                                                   ` Ingo Molnar
2004-12-14 23:21                                                                                 ` Fernando Lopez-Lezcano
2004-12-15  0:43                                                                                   ` Florian Schmidt
2004-12-15  1:09                                                                                   ` Lee Revell
2004-12-15  2:04                                                                                     ` Fernando Lopez-Lezcano
2004-12-15  9:09                                                                                       ` Ingo Molnar
2004-12-15 10:17                                                                                         ` Andrew Walrond
2004-12-15 16:51                                                                                         ` Lee Revell
2004-12-17  0:45                                                                                   ` Fernando Lopez-Lezcano
2004-12-15 20:52                                                                                 ` Magnus Määttä
2005-01-04  6:40                                                                                 ` Bill Huey
2005-01-04  9:45                                                                                   ` [patch] Real-Time Preemption, -RT-2.6.10-mm1-V0.7.34-00 Ingo Molnar
2005-01-04 10:48                                                                                     ` Bill Huey
2005-01-04 10:52                                                                                       ` Ingo Molnar
2005-01-04 10:55                                                                                     ` Felipe Alfaro Solana
2005-01-06 18:45                                                                                     ` Florian Schmidt
2005-01-07 19:26                                                                                     ` Tom Rini
2005-01-07 19:36                                                                                       ` Lee Revell
2005-01-26  8:09                                                                                       ` [patch] Real-Time Preemption, -RT-2.6.11-rc2-V0.7.36-04 Ingo Molnar
2005-02-01 20:01                                                                                         ` Lee Revell
2005-02-01 20:17                                                                                           ` Ingo Molnar
2005-02-01 20:31                                                                                             ` Lee Revell
2005-02-01 20:44                                                                                               ` Ingo Molnar
2005-02-01 23:45                                                                                                 ` Lee Revell
2005-02-02  7:06                                                                                                   ` Ingo Molnar
2005-01-15 13:34                                                                                     ` [patch] Real-Time Preemption, -RT-2.6.11-rc1-V0.7.35-00 Ingo Molnar
2005-01-15 15:16                                                                                       ` K.R. Foley
2005-01-15 19:29                                                                                       ` [patch] Real-Time Preemption, -RT-2.6.11-rc1-V0.7.35-01 Gene Heskett
2005-01-21 20:34                                                                                       ` [patch] Real-Time Preemption, -RT-2.6.11-rc1-V0.7.35-00 K.R. Foley
2005-01-22 12:29                                                                                       ` [patch] Real-Time Preemption, -RT-2.6.11-rc2-V0.7.36-00 Ingo Molnar
2005-01-22 21:22                                                                                         ` Gene Heskett
2005-01-23  9:27                                                                                           ` andyliu
2005-01-23 11:31                                                                                             ` Ingo Molnar
2005-01-23 14:40                                                                                               ` Gene Heskett
2005-01-24  1:01                                                                                                 ` andyliu
2005-01-24  2:54                                                                                                   ` Gene Heskett
2005-01-24  8:02                                                                                           ` Ingo Molnar
2005-01-24 10:42                                                                                             ` Gene Heskett
2005-01-26  1:05                                                                                             ` Lee Revell
2005-02-01 20:14                                                                                         ` [patch] Real-Time Preemption, -RT-2.6.11-rc2-V0.7.37-02 Ingo Molnar
2005-02-03 20:53                                                                                           ` Eugeny S. Mints
2005-02-03 20:55                                                                                             ` Ingo Molnar
2005-02-04  1:51                                                                                           ` Steven Rostedt
2005-02-04  2:18                                                                                             ` Steven Rostedt
2005-02-05  6:02                                                                                               ` Steven Rostedt
2005-02-05  7:59                                                                                                 ` Ingo Molnar
2005-02-05 14:32                                                                                                   ` Steven Rostedt
2005-02-07  9:22                                                                                                     ` Ingo Molnar
2004-11-24 19:23                                                                       ` [patch] Real-Time Preemption, -RT-2.6.10-rc2-mm2-V0.7.30-9 Fernando Lopez-Lezcano
2004-11-24 22:17                                                                         ` Ingo Molnar
2004-11-24 21:56                                                                           ` Fernando Lopez-Lezcano
     [not found]                                                               ` <1100732223.3472.10.camel@localhost>
2004-11-18 15:54                                                                 ` [patch] Real-Time Preemption, -RT-2.6.10-rc2-mm1-V0.7.28-0 Ingo Molnar
2004-11-18 15:07                                                                   ` Christian Meder
2004-11-18 20:42                                                                     ` Ingo Molnar
2004-11-18 22:41                                                                       ` Christian Meder
2004-11-18 22:33                                                                   ` Christian Meder
2004-11-08 22:21                                               ` [patch] Real-Time Preemption, -RT-2.6.10-rc1-mm3-V0.7.19 Adam Heath
2004-10-22 21:44                                   ` [patch] Real-Time Preemption, -RT-2.6.9-mm1-U10 Gene Heskett
2004-10-22 18:41                                 ` [patch] Real-Time Preemption, -RT-2.6.9-rc4-mm1-U9.3 Alexander Batyrshin
2004-10-22 20:08                                   ` Ingo Molnar
2004-10-19 18:54                         ` [patch] Real-Time Preemption, -RT-2.6.9-rc4-mm1-U6 Adam Heath
2004-10-19 20:52                         ` Michal Schmidt
2004-10-20 16:31                         ` Adam Heath
2004-10-19 12:57                       ` [patch] Real-Time Preemption, -RT-2.6.9-rc4-mm1-U5 Kevin Hilman
2004-10-19 13:04                         ` Ingo Molnar
2004-10-15 11:22               ` [patch] Real-Time Preemption, -VP-2.6.9-rc4-mm1-U1 Florian Schmidt
2004-10-15 11:44                 ` Ingo Molnar
2004-10-15 12:25                   ` Florian Schmidt
2004-10-14 18:52             ` [patch] Real-Time Preemption, -VP-2.6.9-rc4-mm1-U0 Daniel Walker
2004-10-14 19:28               ` Ingo Molnar
2004-10-14 19:43                 ` Dipankar Sarma
2004-10-14 20:30               ` Bill Huey
2004-10-14 20:02             ` Daniel Walker
2004-10-14 20:23               ` Ingo Molnar
2004-10-14 22:13             ` Radoslaw Szkodzinski
2004-10-14 22:40             ` Karim Yaghmour
2004-10-14 23:46               ` Ingo Molnar
2004-10-15  0:07                 ` Karim Yaghmour
2004-10-15  0:31                   ` Roland Dreier
2004-10-15  1:22                     ` Karim Yaghmour
2004-10-15  2:00                     ` Robert Wisniewski
2004-10-15  2:21                       ` Lee Revell
2004-10-15 12:27                         ` Robert Wisniewski
2004-10-15  6:59                   ` Ingo Molnar
2004-10-15 12:32                     ` Robert Wisniewski
2004-10-15 13:11                       ` Ingo Molnar
2004-10-15 14:50                         ` Robert Wisniewski
2004-10-15 14:58                           ` Ingo Molnar
  -- strict thread matches above, loose matches on Subject: below --
2004-10-19 22:00 [patch] Real-Time Preemption, -RT-2.6.9-rc4-mm1-U7 Mark_H_Johnson

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1098248541.12223.1450.camel@thomas \
    --to=tglx@linutronix.de \
    --cc=Mark_H_Johnson@Raytheon.com \
    --cc=bhuey@lnxw.com \
    --cc=doogie@debian.org \
    --cc=kr@cybsft.com \
    --cc=linux-kernel@vger.kernel.org \
    --cc=mingo@elte.hu \
    --cc=mista.tapas@gmx.net \
    --cc=nando@ccrma.Stanford.EDU \
    --cc=rlrevell@joe-job.com \
    --cc=rncbc@rncbc.org \
    --cc=xschmi00@stud.feec.vutbr.cz \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.
diff --exclude='*~' -urN 2.6.9-rc4-mm1-RT-U7/drivers/base/driver.c 2.6.9-rc4-mm1-RT-U7-work/drivers/base/driver.c
--- 2.6.9-rc4-mm1-RT-U7/drivers/base/driver.c	2004-10-12 09:41:05.000000000 +0200
+++ 2.6.9-rc4-mm1-RT-U7-work/drivers/base/driver.c	2004-10-20 03:11:20.000000000 +0200
@@ -79,14 +79,13 @@
  *	since most of the things we have to do deal with the bus
  *	structures.
  *
- *	The one interesting aspect is that we initialize @drv->unload_sem
- *	to a locked state here. It will be unlocked when the driver
- *	reference count reaches 0.
+ *	We init the completion strcut here. When the reference 
+ *	count reaches zero, complete() is called from bus_release().
  */
 int driver_register(struct device_driver * drv)
 {
 	INIT_LIST_HEAD(&drv->devices);
-	init_MUTEX_LOCKED(&drv->unload_sem);
+	init_completion(&drv->unload_done);
 	return bus_add_driver(drv);
 }
 
@@ -97,18 +96,16 @@
  *
  *	Again, we pass off most of the work to the bus-level call.
  *
  *	Though, once that is done, we attempt to take @drv->unload_sem.
  *	This will block until the driver refcount reaches 0, and it is
  *	released. Only modular drivers will call this function, and we
  *	have to guarantee that it won't complete, letting the driver
  *	unload until all references are gone.
  */
-
 void driver_unregister(struct device_driver * drv)
 {
 	bus_remove_driver(drv);
-	down(&drv->unload_sem);
-	up(&drv->unload_sem);
+	wait_for_completion(&drv->unload_done);
 }
 
 /**
@@ -97,18 +96,16 @@
  *	Again, we pass off most of the work to the bus-level call.
  *
- *	Though, once that is done, we attempt to take @drv->unload_sem.
- *	This will block until the driver refcount reaches 0, and it is
- *	released. Only modular drivers will call this function, and we
+ *	Though, once that is done, we wait until the driver refcount 
+ *	reaches 0, and complete() is called in bus_release().
+ *	Only modular drivers will call this function, and we
  *	have to guarantee that it won't complete, letting the driver
  *	unload until all references are gone.

[-- Attachment #3: scsi.patch --]
[-- Type: text/x-patch, Size: 2889 bytes --]
